@@ -1,9 +1,15 @@
 import numpy as np
 import requests
-import json
+import tempfile
+import os
+import random
+
 
 class Forefront:
-    def __call__(self, endpoint, data, key):
+    def __init__(self, key):
+        self.key = key
+
+    def __call__(self, endpoint, data):
         if endpoint is None:
             raise Exception('Must include and endpoint')
         if data is None:
@@ -11,22 +17,29 @@ class Forefront:
         if not isinstance(data, np.ndarray):
             raise Exception('Data must be a numpy.ndarray')
 
-        jsonified_data = json.dumps(data.tolist())
+        directory = tempfile.gettempdir()
+        path = os.path.join(directory, f'{random.randint(10000, 100000)}.npy')
+        np.save(path, data)
 
-        res = requests.post(endpoint, data=jsonified_data,
-                            headers={'Content-Type': 'application/json', 'authorization': f"Bearer {key}"})
 
-        if (res.status_code == 404):
+        files = {'model_file':  open(path, 'rb')}
+        res = requests.post(endpoint, files=files, headers={
+            'authorization': f"Bearer {self.key}"
+        })
+
+        os.remove(path);
+
+        if(res.status_code == 404):
             raise Exception('Endpoint is down!')
 
-        if (res.status_code == 401):
+        if(res.status_code == 401):
             raise Exception('Your authentication is wrong!')
 
-        if (res.status_code != 200):
+        if(res.status_code != 200):
             print(res.text)
             raise Exception('Something went wrong with the request!')
 
         try:
             return res.json()
-        except:
+        except Exception:
             raise Exception('Endpoint response is malformed!')
